==========
Developing
==========

.. note::
   This page is still under construction...

All classes and functions are designed for easy extension and implementation
of new metholody.

.. toctree::
   :maxdepth: 1
   guidelines
   design
